summaryrefslogtreecommitdiffstats
path: root/config/config.def.c
diff options
context:
space:
mode:
Diffstat (limited to 'config/config.def.c')
-rw-r--r--config/config.def.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/config/config.def.c b/config/config.def.c
index 4b4139bd..8ab8bf27 100644
--- a/config/config.def.c
+++ b/config/config.def.c
@@ -29,9 +29,9 @@
#include "rofi.h"
Settings config = {
- /** List of enabled switchers. */
- /** -switchers */
- .switchers = "window,run,ssh",
+ /** List of enabled modi. */
+ /** -modi */
+ .modi = "window,run,ssh",
/** Set the default window opacity. */
/** This option only works when running a composite manager. */
/** -o */
@@ -118,7 +118,7 @@ Settings config = {
.separator = '\n',
/** Height of an element in #chars */
.element_height = 1,
/** Sidebar mode, show the switchers */
.sidebar_mode = FALSE,
/** Lazy mode setting */
.lazy_filter_limit = 15000,
@@ -118,7 +118,7 @@ Settings config = {
/** Height of an element in #chars */
.element_height = 1,
- /** Sidebar mode, show the switchers */
+ /** Sidebar mode, show the modi */
.sidebar_mode = FALSE,
/** Lazy mode setting */